mozart
======

.. automodule:: abjad.demos.mozart

.. only:: html

   Functions
   ---------

   .. autosummary::

      ~abjad.demos.mozart.choose_mozart_measures.choose_mozart_measures
      ~abjad.demos.mozart.make_mozart_lilypond_file.make_mozart_lilypond_file
      ~abjad.demos.mozart.make_mozart_measure.make_mozart_measure
      ~abjad.demos.mozart.make_mozart_measure_corpus.make_mozart_measure_corpus
      ~abjad.demos.mozart.make_mozart_score.make_mozart_score
